
<?php
if ( ! function_exists( 'varg_meta' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 */
function varg_meta() {
?>
	<footer class="meta">

	<?php
	$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';

	$time_string = sprintf( $time_string,
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() ),
		esc_attr( get_the_modified_date( 'c' ) ),
		esc_html( get_the_modified_date() )
	);

	$posted_on = sprintf( _x( 'Posted on %s', 'post date', 'varg' ), $time_string);

	$byline = sprintf(
		_x( 'by %s', 'post author', 'varg' ),
		'<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span>'
	);

	echo '<span class="posted-on">' . $posted_on . '</span><span class="byline"> ' . $byline . '</span> ';

	// Hide category and tag text for pages.
	if ( 'post' == get_post_type() ) {
		/* translators: used between list items, there is a space after the comma */
		$categories_list = get_the_category_list( __( ', ', 'varg' ) );
		if ( $categories_list && varg_categorized_blog() ) {
			printf( '<span class="cat-links">' . __( 'Posted in %1$s', 'varg' ) . '</span>', $categories_list );
		}
		echo ' ';
		/* translators: used between list items, there is a space after the comma */
		$tags_list = get_the_tag_list( '', __( ', ', 'varg' ) );
		if ( $tags_list ) {
			printf( '<span class="tags-links">' . __( 'Tagged %1$s', 'varg' ) . '</span>', $tags_list );
		}
	}

	echo '<br/>';

	if ( ! is_single() && ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
		echo '<span class="comments-link">';
		comments_popup_link( __( 'Leave a comment', 'varg' ), __( '1 Comment', 'varg' ), __( '% Comments', 'varg' ) );
		echo '</span>&nbsp;&nbsp;&nbsp;';
	}
	
	/* translators: % is the post title */
	edit_post_link( sprintf( __( 'Edit %s', 'varg' ), get_the_title() ), '<span class="edit-link">', '</span>' );
	
	echo'</footer>';
}
endif;



function varg_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'varg_categories' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,

			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'varg_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		// This blog has more than 1 category so varg_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so varg_categorized_blog should return false.
		return false;
	}
}

/**
 * Flush out the transients used in varg_categorized_blog.
 */
function varg_category_transient_flusher() {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}
	// Like, beat it. Dig?
	delete_transient( 'varg_categories' );
}
add_action( 'edit_category', 'varg_category_transient_flusher' );
add_action( 'save_post',     'varg_category_transient_flusher' );
